package com.xhly.manageapp.service.websocket

import android.app.Notification
import android.app.NotificationChannel
import android.app.NotificationManager
import android.app.Service
import android.content.ComponentName
import android.content.Context
import android.content.Intent
import android.os.Build
import android.widget.Toast
import com.xhly.corelib.Const
import com.xhly.corelib.eventbus.UIEvent
import com.xhly.corelib.network.RetrofitService
import com.xhly.corelib.utils.LogShow
import com.xhly.corelib.utils.SharedPreferencesUtils
import com.xhly.manageapp.bean.LogdOperateBean
import com.xhly.manageapp.network.LogService
import com.xhly.websocket.service.LongConnService
import com.xhly.websocket.utils.SocketPushUtils.dealPushMessage
import kotlinx.coroutines.CoroutineScope
import kotlinx.coroutines.GlobalScope
import kotlinx.coroutines.MainScope
import kotlinx.coroutines.cancel
import kotlinx.coroutines.launch
import org.greenrobot.eventbus.EventBus
import org.greenrobot.eventbus.Subscribe
import org.greenrobot.eventbus.ThreadMode

open class AppSocketService : LongConnService() {
    var CHANNEL_ID = "1"
    var CHANNEL_NAME = "通知"
    var logService = RetrofitService.create<LogService>()
    private val serviceScope = CoroutineScope(MainScope().coroutineContext)

    /*  private var csdkManager: CSDKManager? = null*/
    val spUtils by lazy { SharedPreferencesUtils.getInstance(this) }

    companion object {
        fun openWebSocket(context: Context) {
            context.startService(Intent(context, AppSocketService::class.java))
        }

        fun closeWebSocket(context: Context) {
            context.stopService(Intent(context, AppSocketService::class.java))
        }
    }

    override fun onCreate() {
        super.onCreate()
        EventBus.getDefault().register(this)
        connectUrl = "wss://api.stsotc.com/api/ws"
        /*   csdkManager = CSDKManager(this)*/
        /* startNotification()*/
    }

    override fun processTextMessage(text: String) {
        //Log.v("websocket收到的消息", text);
        dealPushMessage(text)
    }

    override fun onConnectedSuccess() {
        super.onConnectedSuccess()
        UIEvent(Const.UPDATE_CONNECTED_SUCCESS).post()
    }

    @Subscribe(threadMode = ThreadMode.MAIN)
    fun onUiEvent(uiEvent: UIEvent) {
        /* if (csdkManager == null) {
             csdkManager = CSDKManager(this)
         }*/
        when (uiEvent.event) {
            Const.CODE2001.toString() -> {
                Toast.makeText(this, "这就是新消息", Toast.LENGTH_LONG).show()
            }

            Const.CODE2002.toString() -> {
                Toast.makeText(this, "限制使用", Toast.LENGTH_LONG).show()
                spUtils.setParam(Const.DISABLEAPP, true)
                goMainActivity()
            }

            Const.CODE2005.toString() -> {
                //csdkManager?.rebootDevice()
            }

            Const.CODE2006.toString() -> {
                //csdkManager?.launchFactoryReset()
            }

            "10086" -> {
                serviceScope.launch {
                    logService.postLogdoperateAdd(LogdOperateBean())
                }
                Toast.makeText(this, "违规操作，安装未知应用", Toast.LENGTH_LONG).show()
                goMainActivity()
            }
        }
    }

    private fun goMainActivity() {
        try {
            // 为应用程序的启动Activity 准备Intent
            val launchIntent = Intent()
            launchIntent.setComponent(
                ComponentName(
                    "com.xhly.manageapp",
                    "com.xhly.manageapp.ui.MainActivity"
                )
            )
            launchIntent.addFlags(Intent.FLAG_ACTIVITY_NEW_TASK)
            startActivity(launchIntent)
        } catch (e: Exception) {
            LogShow("跳转失败$e")
        }
    }

    override fun onDestroy() {
        super.onDestroy()
        EventBus.getDefault().unregister(this)
        serviceScope.cancel()
        stopForeground(Service.STOP_FOREGROUND_REMOVE)
        /*  val intent=Intent(this,ManageService::class.java)
          startService(intent)*/
    }

    private fun startNotification() {
        var channel: NotificationChannel? = null
        if (Build.VERSION.SDK_INT >= Build.VERSION_CODES.O) {
            channel =
                NotificationChannel(CHANNEL_ID, CHANNEL_NAME, NotificationManager.IMPORTANCE_HIGH)
            val manager = getSystemService(NOTIFICATION_SERVICE) as NotificationManager
            manager.createNotificationChannel(channel)
            val notification = Notification.Builder(
                applicationContext, CHANNEL_ID
            ).build()
            startForeground(1, notification)
        }
    }
}
